# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_team.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_team.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n!dota_gcmessages_client_team.proto\"V\n\x15\x43MsgDOTATeamMemberSDO\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08team_ids\x18\x02 \x03(\r\x12\x17\n\x0fprofile_team_id\x18\x03 \x01(\r\"<\n\x14\x43MsgDOTATeamAdminSDO\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08team_ids\x18\x02 \x03(\r\"=\n\x12\x43MsgDOTATeamMember\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0btime_joined\x18\x04 \x01(\r\"\xde\x04\n\x0c\x43MsgDOTATeam\x12$\n\x07members\x18\x01 \x03(\x0b\x32\x13.CMsgDOTATeamMember\x12\x0f\n\x07team_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64min_id\x18\x05 \x01(\r\x12\x14\n\x0ctime_created\x18\x06 \x01(\r\x12\x11\n\tdisbanded\x18\x07 \x01(\x08\x12\x0c\n\x04wins\x18\x08 \x01(\r\x12\x0e\n\x06losses\x18\t \x01(\r\x12\x0c\n\x04rank\x18\n \x01(\r\x12#\n\x1b\x63\x61libration_games_remaining\x18\x18 \x01(\r\x12\x0c\n\x04logo\x18\x0b \x01(\x04\x12\x11\n\tbase_logo\x18\x0c \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\r \x01(\x04\x12\x14\n\x0csponsor_logo\x18\x0e \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x0f \x01(\t\x12\x0b\n\x03url\x18\x10 \x01(\t\x12\x17\n\x0f\x66ullgamesplayed\x18\x11 \x01(\r\x12\x0f\n\x07leagues\x18\x12 \x03(\r\x12\x13\n\x0bgamesplayed\x18\x13 \x01(\r\x12$\n\x1cgamesplayedwithcurrentroster\x18\x14 \x01(\r\x12\"\n\x1ateammatchmakinggamesplayed\x18\x15 \x01(\r\x12\x1a\n\x12lastplayedgametime\x18\x16 \x01(\r\x12\x16\n\x0elastrenametime\x18\x17 \x01(\r\x12\x18\n\x10recent_match_ids\x18\x19 \x03(\x04\x12\x15\n\rtop_match_ids\x18\x1a \x03(\x04\x12\x13\n\x0bpickup_team\x18\x1b \x01(\x08\"\xdd\x04\n\x10\x43MsgDOTATeamInfo\x12)\n\x07members\x18\x01 \x03(\x0b\x32\x18.CMsgDOTATeamInfo.Member\x12\x0f\n\x07team_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x14\n\x0ctime_created\x18\x05 \x01(\r\x12\x0b\n\x03pro\x18\x06 \x01(\x08\x12\x0e\n\x06locked\x18\x07 \x01(\x08\x12\x13\n\x0bpickup_team\x18\x08 \x01(\x08\x12\x10\n\x08ugc_logo\x18\t \x01(\x04\x12\x15\n\rugc_base_logo\x18\n \x01(\x04\x12\x17\n\x0fugc_banner_logo\x18\x0b \x01(\x04\x12\x18\n\x10ugc_sponsor_logo\x18\x0c \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\r \x01(\t\x12\x0b\n\x03url\x18\x0e \x01(\t\x12\x0c\n\x04wins\x18\x0f \x01(\r\x12\x0e\n\x06losses\x18\x10 \x01(\r\x12\x0c\n\x04rank\x18\x11 \x01(\r\x12#\n\x1b\x63\x61libration_games_remaining\x18\x12 \x01(\r\x12\x1a\n\x12games_played_total\x18\x13 \x01(\r\x12 \n\x18games_played_matchmaking\x18\x14 \x01(\r\x12\x1c\n\x14leagues_participated\x18\x15 \x03(\r\x12\x15\n\rtop_match_ids\x18\x16 \x03(\x04\x12\x18\n\x10recent_match_ids\x18\x17 \x03(\x04\x1aM\n\x06Member\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\r\n\x05\x61\x64min\x18\x03 \x01(\x08\x12\x0b\n\x03sub\x18\x04 \x01(\x08\"H\n\x11\x43MsgDOTATeamsInfo\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12 \n\x05teams\x18\x02 \x03(\x0b\x32\x11.CMsgDOTATeamInfo\"\x1b\n\x19\x43MsgDOTAMyTeamInfoRequest\"\xb3\x01\n\x12\x43MsgDOTACreateTeam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0c\n\x04logo\x18\x03 \x01(\x04\x12\x11\n\tbase_logo\x18\x04 \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\x05 \x01(\x04\x12\x14\n\x0csponsor_logo\x18\x06 \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x07 \x01(\t\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x13\n\x0bpickup_team\x18\t \x01(\x08\"\x97\x04\n\x1a\x43MsgDOTACreateTeamResponse\x12;\n\x06result\x18\x01 \x01(\x0e\x32\".CMsgDOTACreateTeamResponse.Result:\x07INVALID\x12\x0f\n\x07team_id\x18\x02 \x01(\r\"\xaa\x03\n\x06Result\x12\x14\n\x07INVALID\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nNAME_EMPTY\x10\x01\x12\x17\n\x13NAME_BAD_CHARACTERS\x10\x02\x12\x0e\n\nNAME_TAKEN\x10\x03\x12\x11\n\rNAME_TOO_LONG\x10\x04\x12\r\n\tTAG_EMPTY\x10\x05\x12\x16\n\x12TAG_BAD_CHARACTERS\x10\x06\x12\r\n\tTAG_TAKEN\x10\x07\x12\x10\n\x0cTAG_TOO_LONG\x10\x08\x12\x10\n\x0c\x43REATOR_BUSY\x10\t\x12\x15\n\x11UNSPECIFIED_ERROR\x10\n\x12\x1e\n\x1a\x43REATOR_TEAM_LIMIT_REACHED\x10\x0b\x12\x0b\n\x07NO_LOGO\x10\x0c\x12\"\n\x1e\x43REATOR_TEAM_CREATION_COOLDOWN\x10\r\x12\x16\n\x12LOGO_UPLOAD_FAILED\x10\x0e\x12\x1d\n\x19NAME_CHANGED_TOO_RECENTLY\x10\x0f\x12\x1e\n\x1a\x43REATOR_INSUFFICIENT_LEVEL\x10\x10\x12\x18\n\x14INVALID_ACCOUNT_TYPE\x10\x11\"\xcd\x01\n\x17\x43MsgDOTAEditTeamDetails\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\x04\x12\x11\n\tbase_logo\x18\x05 \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\x06 \x01(\x04\x12\x14\n\x0csponsor_logo\x18\x07 \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x17\n\x0fin_use_by_party\x18\n \x01(\x08\"\xed\x01\n\x1f\x43MsgDOTAEditTeamDetailsResponse\x12@\n\x06result\x18\x01 \x01(\x0e\x32\'.CMsgDOTAEditTeamDetailsResponse.Result:\x07SUCCESS\"\x87\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12 \n\x1c\x46\x41ILURE_INVALID_ACCOUNT_TYPE\x10\x01\x12\x16\n\x12\x46\x41ILURE_NOT_MEMBER\x10\x02\x12\x17\n\x13\x46\x41ILURE_TEAM_LOCKED\x10\x03\x12\x1d\n\x19\x46\x41ILURE_UNSPECIFIED_ERROR\x10\x04\"K\n\x1b\x43MsgDOTATeamProfileResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\x12\x1b\n\x04team\x18\x02 \x01(\x0b\x32\r.CMsgDOTATeam\"\x1c\n\x1a\x43MsgDOTAProTeamListRequest\"\xe0\x01\n\x1b\x43MsgDOTAProTeamListResponse\x12\x35\n\x05teams\x18\x01 \x03(\x0b\x32&.CMsgDOTAProTeamListResponse.TeamEntry\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\x1ay\n\tTeamEntry\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x14\n\x0ctime_created\x18\x03 \x01(\r\x12\x0c\n\x04logo\x18\x04 \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x05 \x01(\t\x12\x14\n\x0cmember_count\x18\x06 \x01(\r\"E\n\x1e\x43MsgDOTATeamInvite_InviterToGC\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07team_id\x18\x02 \x01(\r\"\x9e\x01\n/CMsgDOTATeamInvite_GCImmediateResponseToInviter\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\x12.ETeamInviteResult:\x13TEAM_INVITE_SUCCESS\x12\x14\n\x0cinvitee_name\x18\x02 \x01(\t\x12\x1c\n\x14required_badge_level\x18\x03 \x01(\r\"v\n%CMsgDOTATeamInvite_GCRequestToInvitee\x12\x1a\n\x12inviter_account_id\x18\x01 \x01(\r\x12\x11\n\tteam_name\x18\x02 \x01(\t\x12\x10\n\x08team_tag\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\x04\"a\n&CMsgDOTATeamInvite_InviteeResponseToGC\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\x12.ETeamInviteResult:\x13TEAM_INVITE_SUCCESS\"w\n&CMsgDOTATeamInvite_GCResponseToInviter\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\x12.ETeamInviteResult:\x13TEAM_INVITE_SUCCESS\x12\x14\n\x0cinvitee_name\x18\x02 \x01(\t\"t\n&CMsgDOTATeamInvite_GCResponseToInvitee\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\x12.ETeamInviteResult:\x13TEAM_INVITE_SUCCESS\x12\x11\n\tteam_name\x18\x02 \x01(\t\"=\n\x16\x43MsgDOTAKickTeamMember\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07team_id\x18\x02 \x01(\r\"\x90\x02\n\x1e\x43MsgDOTAKickTeamMemberResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32&.CMsgDOTAKickTeamMemberResponse.Result:\x07SUCCESS\"\xac\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12 \n\x1c\x46\x41ILURE_INVALID_ACCOUNT_TYPE\x10\x01\x12\x1c\n\x18\x46\x41ILURE_KICKER_NOT_ADMIN\x10\x02\x12\x1d\n\x19\x46\x41ILURE_KICKEE_NOT_MEMBER\x10\x03\x12\x17\n\x13\x46\x41ILURE_TEAM_LOCKED\x10\x04\x12\x1d\n\x19\x46\x41ILURE_UNSPECIFIED_ERROR\x10\x05\"J\n\x19\x43MsgDOTATransferTeamAdmin\x12\x1c\n\x14new_admin_account_id\x18\x01 \x01(\r\x12\x0f\n\x07team_id\x18\x02 \x01(\r\"\x89\x02\n!CMsgDOTATransferTeamAdminResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32).CMsgDOTATransferTeamAdminResponse.Result:\x07SUCCESS\"\x9f\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12 \n\x1c\x46\x41ILURE_INVALID_ACCOUNT_TYPE\x10\x01\x12\x15\n\x11\x46\x41ILURE_NOT_ADMIN\x10\x02\x12\x18\n\x14\x46\x41ILURE_SAME_ACCOUNT\x10\x03\x12\x16\n\x12\x46\x41ILURE_NOT_MEMBER\x10\x04\x12\x1d\n\x19\x46\x41ILURE_UNSPECIFIED_ERROR\x10\x05\"[\n\x15\x43MsgDOTAChangeTeamSub\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x19\n\x11member_account_id\x18\x02 \x01(\r\x12\x16\n\x0esub_account_id\x18\x03 \x01(\r\"\xaf\x02\n\x1d\x43MsgDOTAChangeTeamSubResponse\x12>\n\x06result\x18\x01 \x01(\x0e\x32%.CMsgDOTAChangeTeamSubResponse.Result:\x07SUCCESS\"\xcd\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12 \n\x1c\x46\x41ILURE_INVALID_ACCOUNT_TYPE\x10\x01\x12\x18\n\x14\x46\x41ILURE_SAME_ACCOUNT\x10\x02\x12\x15\n\x11\x46\x41ILURE_NOT_ADMIN\x10\x03\x12\x16\n\x12\x46\x41ILURE_NOT_MEMBER\x10\x04\x12\x13\n\x0f\x46\x41ILURE_NOT_SUB\x10\x05\x12\x17\n\x13\x46\x41ILURE_ALREADY_SUB\x10\x06\x12\x1d\n\x19\x46\x41ILURE_UNSPECIFIED_ERROR\x10\x07\"$\n\x11\x43MsgDOTALeaveTeam\x12\x0f\n\x07team_id\x18\x01 \x01(\r\"\xbe\x01\n\x19\x43MsgDOTALeaveTeamResponse\x12:\n\x06result\x18\x01 \x01(\x0e\x32!.CMsgDOTALeaveTeamResponse.Result:\x07SUCCESS\"e\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x16\n\x12\x46\x41ILURE_NOT_MEMBER\x10\x01\x12\x17\n\x13\x46\x41ILURE_TEAM_LOCKED\x10\x02\x12\x1d\n\x19\x46\x41ILURE_UNSPECIFIED_ERROR\x10\x03\"2\n\x19\x43MsgDOTABetaParticipation\x12\x15\n\raccess_rights\x18\x01 \x01(\r*\xda\x04\n\x11\x45TeamInviteResult\x12\x17\n\x13TEAM_INVITE_SUCCESS\x10\x00\x12\'\n#TEAM_INVITE_FAILURE_INVITE_REJECTED\x10\x01\x12&\n\"TEAM_INVITE_FAILURE_INVITE_TIMEOUT\x10\x02\x12*\n&TEAM_INVITE_ERROR_TEAM_AT_MEMBER_LIMIT\x10\x03\x12!\n\x1dTEAM_INVITE_ERROR_TEAM_LOCKED\x10\x04\x12+\n\'TEAM_INVITE_ERROR_INVITEE_NOT_AVAILABLE\x10\x05\x12\"\n\x1eTEAM_INVITE_ERROR_INVITEE_BUSY\x10\x06\x12,\n(TEAM_INVITE_ERROR_INVITEE_ALREADY_MEMBER\x10\x07\x12+\n\'TEAM_INVITE_ERROR_INVITEE_AT_TEAM_LIMIT\x10\x08\x12\x30\n,TEAM_INVITE_ERROR_INVITEE_INSUFFICIENT_LEVEL\x10\t\x12\x32\n.TEAM_INVITE_ERROR_INVITER_INVALID_ACCOUNT_TYPE\x10\n\x12\'\n#TEAM_INVITE_ERROR_INVITER_NOT_ADMIN\x10\x0b\x12.\n*TEAM_INVITE_ERROR_INCORRECT_USER_RESPONDED\x10\x0c\x12!\n\x1dTEAM_INVITE_ERROR_UNSPECIFIED\x10\rB\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ETEAMINVITERESULT = _descriptor.EnumDescriptor(
  name='ETeamInviteResult',
  full_name='ETeamInviteResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_FAILURE_INVITE_REJECTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_FAILURE_INVITE_TIMEOUT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_TEAM_AT_MEMBER_LIMIT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_TEAM_LOCKED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITEE_NOT_AVAILABLE', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITEE_BUSY', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITEE_ALREADY_MEMBER', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITEE_AT_TEAM_LIMIT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITEE_INSUFFICIENT_LEVEL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITER_INVALID_ACCOUNT_TYPE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INVITER_NOT_ADMIN', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_INCORRECT_USER_RESPONDED', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_INVITE_ERROR_UNSPECIFIED', index=13, number=13,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5127,
  serialized_end=5729,
)
_sym_db.RegisterEnumDescriptor(_ETEAMINVITERESULT)

ETeamInviteResult = enum_type_wrapper.EnumTypeWrapper(_ETEAMINVITERESULT)
TEAM_INVITE_SUCCESS = 0
TEAM_INVITE_FAILURE_INVITE_REJECTED = 1
TEAM_INVITE_FAILURE_INVITE_TIMEOUT = 2
TEAM_INVITE_ERROR_TEAM_AT_MEMBER_LIMIT = 3
TEAM_INVITE_ERROR_TEAM_LOCKED = 4
TEAM_INVITE_ERROR_INVITEE_NOT_AVAILABLE = 5
TEAM_INVITE_ERROR_INVITEE_BUSY = 6
TEAM_INVITE_ERROR_INVITEE_ALREADY_MEMBER = 7
TEAM_INVITE_ERROR_INVITEE_AT_TEAM_LIMIT = 8
TEAM_INVITE_ERROR_INVITEE_INSUFFICIENT_LEVEL = 9
TEAM_INVITE_ERROR_INVITER_INVALID_ACCOUNT_TYPE = 10
TEAM_INVITE_ERROR_INVITER_NOT_ADMIN = 11
TEAM_INVITE_ERROR_INCORRECT_USER_RESPONDED = 12
TEAM_INVITE_ERROR_UNSPECIFIED = 13


_CMSGDOTACREATETEAMRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTACreateTeamResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_EMPTY', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_BAD_CHARACTERS', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TAKEN', index=4, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TOO_LONG', index=5, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_EMPTY', index=6, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_BAD_CHARACTERS', index=7, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_TAKEN', index=8, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_TOO_LONG', index=9, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATOR_BUSY', index=10, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_ERROR', index=11, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATOR_TEAM_LIMIT_REACHED', index=12, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_LOGO', index=13, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATOR_TEAM_CREATION_COOLDOWN', index=14, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGO_UPLOAD_FAILED', index=15, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_CHANGED_TOO_RECENTLY', index=16, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATOR_INSUFFICIENT_LEVEL', index=17, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ACCOUNT_TYPE', index=18, number=17,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1862,
  serialized_end=2288,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTACREATETEAMRESPONSE_RESULT)

_CMSGDOTAEDITTEAMDETAILSRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTAEditTeamDetailsResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACCOUNT_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_MEMBER', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_TEAM_LOCKED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNSPECIFIED_ERROR', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2601,
  serialized_end=2736,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAEDITTEAMDETAILSRESPONSE_RESULT)

_CMSGDOTAKICKTEAMMEMBERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTAKickTeamMemberResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACCOUNT_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_KICKER_NOT_ADMIN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_KICKEE_NOT_MEMBER', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_TEAM_LOCKED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNSPECIFIED_ERROR', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3926,
  serialized_end=4098,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAKICKTEAMMEMBERRESPONSE_RESULT)

_CMSGDOTATRANSFERTEAMADMINRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTATransferTeamAdminResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACCOUNT_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_ADMIN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SAME_ACCOUNT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_MEMBER', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNSPECIFIED_ERROR', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4283,
  serialized_end=4442,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTATRANSFERTEAMADMINRESPONSE_RESULT)

_CMSGDOTACHANGETEAMSUBRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTAChangeTeamSubResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACCOUNT_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SAME_ACCOUNT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_ADMIN', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_MEMBER', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_SUB', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_ALREADY_SUB', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNSPECIFIED_ERROR', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4636,
  serialized_end=4841,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTACHANGETEAMSUBRESPONSE_RESULT)

_CMSGDOTALEAVETEAMRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTALeaveTeamResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_MEMBER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_TEAM_LOCKED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNSPECIFIED_ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4971,
  serialized_end=5072,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTALEAVETEAMRESPONSE_RESULT)


_CMSGDOTATEAMMEMBERSDO = _descriptor.Descriptor(
  name='CMsgDOTATeamMemberSDO',
  full_name='CMsgDOTATeamMemberSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTATeamMemberSDO.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_ids', full_name='CMsgDOTATeamMemberSDO.team_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile_team_id', full_name='CMsgDOTATeamMemberSDO.profile_team_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=123,
)


_CMSGDOTATEAMADMINSDO = _descriptor.Descriptor(
  name='CMsgDOTATeamAdminSDO',
  full_name='CMsgDOTATeamAdminSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTATeamAdminSDO.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_ids', full_name='CMsgDOTATeamAdminSDO.team_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=185,
)


_CMSGDOTATEAMMEMBER = _descriptor.Descriptor(
  name='CMsgDOTATeamMember',
  full_name='CMsgDOTATeamMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTATeamMember.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_joined', full_name='CMsgDOTATeamMember.time_joined', index=1,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=248,
)


_CMSGDOTATEAM = _descriptor.Descriptor(
  name='CMsgDOTATeam',
  full_name='CMsgDOTATeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTATeam.members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATeam.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTATeam.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTATeam.tag', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='admin_id', full_name='CMsgDOTATeam.admin_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgDOTATeam.time_created', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disbanded', full_name='CMsgDOTATeam.disbanded', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgDOTATeam.wins', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CMsgDOTATeam.losses', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CMsgDOTATeam.rank', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_games_remaining', full_name='CMsgDOTATeam.calibration_games_remaining', index=10,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTATeam.logo', index=11,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTATeam.base_logo', index=12,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTATeam.banner_logo', index=13,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor_logo', full_name='CMsgDOTATeam.sponsor_logo', index=14,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTATeam.country_code', index=15,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgDOTATeam.url', index=16,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fullgamesplayed', full_name='CMsgDOTATeam.fullgamesplayed', index=17,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagues', full_name='CMsgDOTATeam.leagues', index=18,
      number=18, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gamesplayed', full_name='CMsgDOTATeam.gamesplayed', index=19,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gamesplayedwithcurrentroster', full_name='CMsgDOTATeam.gamesplayedwithcurrentroster', index=20,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teammatchmakinggamesplayed', full_name='CMsgDOTATeam.teammatchmakinggamesplayed', index=21,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastplayedgametime', full_name='CMsgDOTATeam.lastplayedgametime', index=22,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastrenametime', full_name='CMsgDOTATeam.lastrenametime', index=23,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_match_ids', full_name='CMsgDOTATeam.recent_match_ids', index=24,
      number=25, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='top_match_ids', full_name='CMsgDOTATeam.top_match_ids', index=25,
      number=26, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickup_team', full_name='CMsgDOTATeam.pickup_team', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=857,
)


_CMSGDOTATEAMINFO_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgDOTATeamInfo.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTATeamInfo.Member.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_joined', full_name='CMsgDOTATeamInfo.Member.time_joined', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='admin', full_name='CMsgDOTATeamInfo.Member.admin', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sub', full_name='CMsgDOTATeamInfo.Member.sub', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1388,
  serialized_end=1465,
)

_CMSGDOTATEAMINFO = _descriptor.Descriptor(
  name='CMsgDOTATeamInfo',
  full_name='CMsgDOTATeamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTATeamInfo.members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATeamInfo.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTATeamInfo.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTATeamInfo.tag', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgDOTATeamInfo.time_created', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pro', full_name='CMsgDOTATeamInfo.pro', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='locked', full_name='CMsgDOTATeamInfo.locked', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickup_team', full_name='CMsgDOTATeamInfo.pickup_team', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_logo', full_name='CMsgDOTATeamInfo.ugc_logo', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_base_logo', full_name='CMsgDOTATeamInfo.ugc_base_logo', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_banner_logo', full_name='CMsgDOTATeamInfo.ugc_banner_logo', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_sponsor_logo', full_name='CMsgDOTATeamInfo.ugc_sponsor_logo', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTATeamInfo.country_code', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgDOTATeamInfo.url', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgDOTATeamInfo.wins', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CMsgDOTATeamInfo.losses', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CMsgDOTATeamInfo.rank', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_games_remaining', full_name='CMsgDOTATeamInfo.calibration_games_remaining', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games_played_total', full_name='CMsgDOTATeamInfo.games_played_total', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games_played_matchmaking', full_name='CMsgDOTATeamInfo.games_played_matchmaking', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagues_participated', full_name='CMsgDOTATeamInfo.leagues_participated', index=20,
      number=21, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='top_match_ids', full_name='CMsgDOTATeamInfo.top_match_ids', index=21,
      number=22, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_match_ids', full_name='CMsgDOTATeamInfo.recent_match_ids', index=22,
      number=23, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTATEAMINFO_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=1465,
)


_CMSGDOTATEAMSINFO = _descriptor.Descriptor(
  name='CMsgDOTATeamsInfo',
  full_name='CMsgDOTATeamsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTATeamsInfo.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTATeamsInfo.teams', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1539,
)


_CMSGDOTAMYTEAMINFOREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAMyTeamInfoRequest',
  full_name='CMsgDOTAMyTeamInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1541,
  serialized_end=1568,
)


_CMSGDOTACREATETEAM = _descriptor.Descriptor(
  name='CMsgDOTACreateTeam',
  full_name='CMsgDOTACreateTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTACreateTeam.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTACreateTeam.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTACreateTeam.logo', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTACreateTeam.base_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTACreateTeam.banner_logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor_logo', full_name='CMsgDOTACreateTeam.sponsor_logo', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTACreateTeam.country_code', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgDOTACreateTeam.url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickup_team', full_name='CMsgDOTACreateTeam.pickup_team', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1571,
  serialized_end=1750,
)


_CMSGDOTACREATETEAMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACreateTeamResponse',
  full_name='CMsgDOTACreateTeamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTACreateTeamResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTACreateTeamResponse.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTACREATETEAMRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1753,
  serialized_end=2288,
)


_CMSGDOTAEDITTEAMDETAILS = _descriptor.Descriptor(
  name='CMsgDOTAEditTeamDetails',
  full_name='CMsgDOTAEditTeamDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAEditTeamDetails.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTAEditTeamDetails.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTAEditTeamDetails.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAEditTeamDetails.logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTAEditTeamDetails.base_logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTAEditTeamDetails.banner_logo', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor_logo', full_name='CMsgDOTAEditTeamDetails.sponsor_logo', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTAEditTeamDetails.country_code', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgDOTAEditTeamDetails.url', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_use_by_party', full_name='CMsgDOTAEditTeamDetails.in_use_by_party', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2291,
  serialized_end=2496,
)


_CMSGDOTAEDITTEAMDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAEditTeamDetailsResponse',
  full_name='CMsgDOTAEditTeamDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAEditTeamDetailsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAEDITTEAMDETAILSRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2499,
  serialized_end=2736,
)


_CMSGDOTATEAMPROFILERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTATeamProfileResponse',
  full_name='CMsgDOTATeamProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTATeamProfileResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTATeamProfileResponse.team', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2738,
  serialized_end=2813,
)


_CMSGDOTAPROTEAMLISTREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAProTeamListRequest',
  full_name='CMsgDOTAProTeamListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2815,
  serialized_end=2843,
)


_CMSGDOTAPROTEAMLISTRESPONSE_TEAMENTRY = _descriptor.Descriptor(
  name='TeamEntry',
  full_name='CMsgDOTAProTeamListResponse.TeamEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAProTeamListResponse.TeamEntry.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTAProTeamListResponse.TeamEntry.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgDOTAProTeamListResponse.TeamEntry.time_created', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAProTeamListResponse.TeamEntry.logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTAProTeamListResponse.TeamEntry.country_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgDOTAProTeamListResponse.TeamEntry.member_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=3070,
)

_CMSGDOTAPROTEAMLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAProTeamListResponse',
  full_name='CMsgDOTAProTeamListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTAProTeamListResponse.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTAProTeamListResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROTEAMLISTRESPONSE_TEAMENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2846,
  serialized_end=3070,
)


_CMSGDOTATEAMINVITE_INVITERTOGC = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_InviterToGC',
  full_name='CMsgDOTATeamInvite_InviterToGC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTATeamInvite_InviterToGC.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATeamInvite_InviterToGC.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3072,
  serialized_end=3141,
)


_CMSGDOTATEAMINVITE_GCIMMEDIATERESPONSETOINVITER = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_GCImmediateResponseToInviter',
  full_name='CMsgDOTATeamInvite_GCImmediateResponseToInviter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATeamInvite_GCImmediateResponseToInviter.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invitee_name', full_name='CMsgDOTATeamInvite_GCImmediateResponseToInviter.invitee_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_badge_level', full_name='CMsgDOTATeamInvite_GCImmediateResponseToInviter.required_badge_level', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3144,
  serialized_end=3302,
)


_CMSGDOTATEAMINVITE_GCREQUESTTOINVITEE = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_GCRequestToInvitee',
  full_name='CMsgDOTATeamInvite_GCRequestToInvitee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inviter_account_id', full_name='CMsgDOTATeamInvite_GCRequestToInvitee.inviter_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTATeamInvite_GCRequestToInvitee.team_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='CMsgDOTATeamInvite_GCRequestToInvitee.team_tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTATeamInvite_GCRequestToInvitee.logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3304,
  serialized_end=3422,
)


_CMSGDOTATEAMINVITE_INVITEERESPONSETOGC = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_InviteeResponseToGC',
  full_name='CMsgDOTATeamInvite_InviteeResponseToGC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATeamInvite_InviteeResponseToGC.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3424,
  serialized_end=3521,
)


_CMSGDOTATEAMINVITE_GCRESPONSETOINVITER = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_GCResponseToInviter',
  full_name='CMsgDOTATeamInvite_GCResponseToInviter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATeamInvite_GCResponseToInviter.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invitee_name', full_name='CMsgDOTATeamInvite_GCResponseToInviter.invitee_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3523,
  serialized_end=3642,
)


_CMSGDOTATEAMINVITE_GCRESPONSETOINVITEE = _descriptor.Descriptor(
  name='CMsgDOTATeamInvite_GCResponseToInvitee',
  full_name='CMsgDOTATeamInvite_GCResponseToInvitee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATeamInvite_GCResponseToInvitee.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTATeamInvite_GCResponseToInvitee.team_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3644,
  serialized_end=3760,
)


_CMSGDOTAKICKTEAMMEMBER = _descriptor.Descriptor(
  name='CMsgDOTAKickTeamMember',
  full_name='CMsgDOTAKickTeamMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAKickTeamMember.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAKickTeamMember.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3762,
  serialized_end=3823,
)


_CMSGDOTAKICKTEAMMEMBERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAKickTeamMemberResponse',
  full_name='CMsgDOTAKickTeamMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAKickTeamMemberResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAKICKTEAMMEMBERRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3826,
  serialized_end=4098,
)


_CMSGDOTATRANSFERTEAMADMIN = _descriptor.Descriptor(
  name='CMsgDOTATransferTeamAdmin',
  full_name='CMsgDOTATransferTeamAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_admin_account_id', full_name='CMsgDOTATransferTeamAdmin.new_admin_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATransferTeamAdmin.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4174,
)


_CMSGDOTATRANSFERTEAMADMINRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTATransferTeamAdminResponse',
  full_name='CMsgDOTATransferTeamAdminResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATransferTeamAdminResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTATRANSFERTEAMADMINRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4177,
  serialized_end=4442,
)


_CMSGDOTACHANGETEAMSUB = _descriptor.Descriptor(
  name='CMsgDOTAChangeTeamSub',
  full_name='CMsgDOTAChangeTeamSub',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAChangeTeamSub.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_account_id', full_name='CMsgDOTAChangeTeamSub.member_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sub_account_id', full_name='CMsgDOTAChangeTeamSub.sub_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4444,
  serialized_end=4535,
)


_CMSGDOTACHANGETEAMSUBRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAChangeTeamSubResponse',
  full_name='CMsgDOTAChangeTeamSubResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAChangeTeamSubResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTACHANGETEAMSUBRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4538,
  serialized_end=4841,
)


_CMSGDOTALEAVETEAM = _descriptor.Descriptor(
  name='CMsgDOTALeaveTeam',
  full_name='CMsgDOTALeaveTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTALeaveTeam.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4843,
  serialized_end=4879,
)


_CMSGDOTALEAVETEAMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALeaveTeamResponse',
  full_name='CMsgDOTALeaveTeamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTALeaveTeamResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTALEAVETEAMRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4882,
  serialized_end=5072,
)


_CMSGDOTABETAPARTICIPATION = _descriptor.Descriptor(
  name='CMsgDOTABetaParticipation',
  full_name='CMsgDOTABetaParticipation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_rights', full_name='CMsgDOTABetaParticipation.access_rights', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5074,
  serialized_end=5124,
)

_CMSGDOTATEAM.fields_by_name['members'].message_type = _CMSGDOTATEAMMEMBER
_CMSGDOTATEAMINFO_MEMBER.containing_type = _CMSGDOTATEAMINFO
_CMSGDOTATEAMINFO.fields_by_name['members'].message_type = _CMSGDOTATEAMINFO_MEMBER
_CMSGDOTATEAMSINFO.fields_by_name['teams'].message_type = _CMSGDOTATEAMINFO
_CMSGDOTACREATETEAMRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTACREATETEAMRESPONSE_RESULT
_CMSGDOTACREATETEAMRESPONSE_RESULT.containing_type = _CMSGDOTACREATETEAMRESPONSE
_CMSGDOTAEDITTEAMDETAILSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAEDITTEAMDETAILSRESPONSE_RESULT
_CMSGDOTAEDITTEAMDETAILSRESPONSE_RESULT.containing_type = _CMSGDOTAEDITTEAMDETAILSRESPONSE
_CMSGDOTATEAMPROFILERESPONSE.fields_by_name['team'].message_type = _CMSGDOTATEAM
_CMSGDOTAPROTEAMLISTRESPONSE_TEAMENTRY.containing_type = _CMSGDOTAPROTEAMLISTRESPONSE
_CMSGDOTAPROTEAMLISTRESPONSE.fields_by_name['teams'].message_type = _CMSGDOTAPROTEAMLISTRESPONSE_TEAMENTRY
_CMSGDOTATEAMINVITE_GCIMMEDIATERESPONSETOINVITER.fields_by_name['result'].enum_type = _ETEAMINVITERESULT
_CMSGDOTATEAMINVITE_INVITEERESPONSETOGC.fields_by_name['result'].enum_type = _ETEAMINVITERESULT
_CMSGDOTATEAMINVITE_GCRESPONSETOINVITER.fields_by_name['result'].enum_type = _ETEAMINVITERESULT
_CMSGDOTATEAMINVITE_GCRESPONSETOINVITEE.fields_by_name['result'].enum_type = _ETEAMINVITERESULT
_CMSGDOTAKICKTEAMMEMBERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAKICKTEAMMEMBERRESPONSE_RESULT
_CMSGDOTAKICKTEAMMEMBERRESPONSE_RESULT.containing_type = _CMSGDOTAKICKTEAMMEMBERRESPONSE
_CMSGDOTATRANSFERTEAMADMINRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTATRANSFERTEAMADMINRESPONSE_RESULT
_CMSGDOTATRANSFERTEAMADMINRESPONSE_RESULT.containing_type = _CMSGDOTATRANSFERTEAMADMINRESPONSE
_CMSGDOTACHANGETEAMSUBRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTACHANGETEAMSUBRESPONSE_RESULT
_CMSGDOTACHANGETEAMSUBRESPONSE_RESULT.containing_type = _CMSGDOTACHANGETEAMSUBRESPONSE
_CMSGDOTALEAVETEAMRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTALEAVETEAMRESPONSE_RESULT
_CMSGDOTALEAVETEAMRESPONSE_RESULT.containing_type = _CMSGDOTALEAVETEAMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTATeamMemberSDO'] = _CMSGDOTATEAMMEMBERSDO
DESCRIPTOR.message_types_by_name['CMsgDOTATeamAdminSDO'] = _CMSGDOTATEAMADMINSDO
DESCRIPTOR.message_types_by_name['CMsgDOTATeamMember'] = _CMSGDOTATEAMMEMBER
DESCRIPTOR.message_types_by_name['CMsgDOTATeam'] = _CMSGDOTATEAM
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInfo'] = _CMSGDOTATEAMINFO
DESCRIPTOR.message_types_by_name['CMsgDOTATeamsInfo'] = _CMSGDOTATEAMSINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAMyTeamInfoRequest'] = _CMSGDOTAMYTEAMINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTACreateTeam'] = _CMSGDOTACREATETEAM
DESCRIPTOR.message_types_by_name['CMsgDOTACreateTeamResponse'] = _CMSGDOTACREATETEAMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAEditTeamDetails'] = _CMSGDOTAEDITTEAMDETAILS
DESCRIPTOR.message_types_by_name['CMsgDOTAEditTeamDetailsResponse'] = _CMSGDOTAEDITTEAMDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTATeamProfileResponse'] = _CMSGDOTATEAMPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAProTeamListRequest'] = _CMSGDOTAPROTEAMLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAProTeamListResponse'] = _CMSGDOTAPROTEAMLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_InviterToGC'] = _CMSGDOTATEAMINVITE_INVITERTOGC
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_GCImmediateResponseToInviter'] = _CMSGDOTATEAMINVITE_GCIMMEDIATERESPONSETOINVITER
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_GCRequestToInvitee'] = _CMSGDOTATEAMINVITE_GCREQUESTTOINVITEE
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_InviteeResponseToGC'] = _CMSGDOTATEAMINVITE_INVITEERESPONSETOGC
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_GCResponseToInviter'] = _CMSGDOTATEAMINVITE_GCRESPONSETOINVITER
DESCRIPTOR.message_types_by_name['CMsgDOTATeamInvite_GCResponseToInvitee'] = _CMSGDOTATEAMINVITE_GCRESPONSETOINVITEE
DESCRIPTOR.message_types_by_name['CMsgDOTAKickTeamMember'] = _CMSGDOTAKICKTEAMMEMBER
DESCRIPTOR.message_types_by_name['CMsgDOTAKickTeamMemberResponse'] = _CMSGDOTAKICKTEAMMEMBERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTATransferTeamAdmin'] = _CMSGDOTATRANSFERTEAMADMIN
DESCRIPTOR.message_types_by_name['CMsgDOTATransferTeamAdminResponse'] = _CMSGDOTATRANSFERTEAMADMINRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAChangeTeamSub'] = _CMSGDOTACHANGETEAMSUB
DESCRIPTOR.message_types_by_name['CMsgDOTAChangeTeamSubResponse'] = _CMSGDOTACHANGETEAMSUBRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALeaveTeam'] = _CMSGDOTALEAVETEAM
DESCRIPTOR.message_types_by_name['CMsgDOTALeaveTeamResponse'] = _CMSGDOTALEAVETEAMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTABetaParticipation'] = _CMSGDOTABETAPARTICIPATION
DESCRIPTOR.enum_types_by_name['ETeamInviteResult'] = _ETEAMINVITERESULT

CMsgDOTATeamMemberSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamMemberSDO', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMMEMBERSDO,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamMemberSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamMemberSDO)

CMsgDOTATeamAdminSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamAdminSDO', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMADMINSDO,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamAdminSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamAdminSDO)

CMsgDOTATeamMember = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamMember', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMMEMBER,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamMember)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamMember)

CMsgDOTATeam = _reflection.GeneratedProtocolMessageType('CMsgDOTATeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAM,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeam)
  ))
_sym_db.RegisterMessage(CMsgDOTATeam)

CMsgDOTATeamInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInfo', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATEAMINFO_MEMBER,
    __module__ = 'dota_gcmessages_client_team_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATeamInfo.Member)
    ))
  ,
  DESCRIPTOR = _CMSGDOTATEAMINFO,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInfo)
_sym_db.RegisterMessage(CMsgDOTATeamInfo.Member)

CMsgDOTATeamsInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamsInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMSINFO,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamsInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamsInfo)

CMsgDOTAMyTeamInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAMyTeamInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMYTEAMINFOREQUEST,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMyTeamInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAMyTeamInfoRequest)

CMsgDOTACreateTeam = _reflection.GeneratedProtocolMessageType('CMsgDOTACreateTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACREATETEAM,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACreateTeam)
  ))
_sym_db.RegisterMessage(CMsgDOTACreateTeam)

CMsgDOTACreateTeamResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACreateTeamResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACREATETEAMRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACreateTeamResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACreateTeamResponse)

CMsgDOTAEditTeamDetails = _reflection.GeneratedProtocolMessageType('CMsgDOTAEditTeamDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEDITTEAMDETAILS,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEditTeamDetails)
  ))
_sym_db.RegisterMessage(CMsgDOTAEditTeamDetails)

CMsgDOTAEditTeamDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAEditTeamDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEDITTEAMDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEditTeamDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAEditTeamDetailsResponse)

CMsgDOTATeamProfileResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamProfileResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMPROFILERESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamProfileResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamProfileResponse)

CMsgDOTAProTeamListRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAProTeamListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPROTEAMLISTREQUEST,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProTeamListRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAProTeamListRequest)

CMsgDOTAProTeamListResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAProTeamListResponse', (_message.Message,), dict(

  TeamEntry = _reflection.GeneratedProtocolMessageType('TeamEntry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROTEAMLISTRESPONSE_TEAMENTRY,
    __module__ = 'dota_gcmessages_client_team_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProTeamListResponse.TeamEntry)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPROTEAMLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProTeamListResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAProTeamListResponse)
_sym_db.RegisterMessage(CMsgDOTAProTeamListResponse.TeamEntry)

CMsgDOTATeamInvite_InviterToGC = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_InviterToGC', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_INVITERTOGC,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_InviterToGC)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_InviterToGC)

CMsgDOTATeamInvite_GCImmediateResponseToInviter = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_GCImmediateResponseToInviter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_GCIMMEDIATERESPONSETOINVITER,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_GCImmediateResponseToInviter)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_GCImmediateResponseToInviter)

CMsgDOTATeamInvite_GCRequestToInvitee = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_GCRequestToInvitee', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_GCREQUESTTOINVITEE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_GCRequestToInvitee)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_GCRequestToInvitee)

CMsgDOTATeamInvite_InviteeResponseToGC = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_InviteeResponseToGC', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_INVITEERESPONSETOGC,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_InviteeResponseToGC)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_InviteeResponseToGC)

CMsgDOTATeamInvite_GCResponseToInviter = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_GCResponseToInviter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_GCRESPONSETOINVITER,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_GCResponseToInviter)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_GCResponseToInviter)

CMsgDOTATeamInvite_GCResponseToInvitee = _reflection.GeneratedProtocolMessageType('CMsgDOTATeamInvite_GCResponseToInvitee', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATEAMINVITE_GCRESPONSETOINVITEE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATeamInvite_GCResponseToInvitee)
  ))
_sym_db.RegisterMessage(CMsgDOTATeamInvite_GCResponseToInvitee)

CMsgDOTAKickTeamMember = _reflection.GeneratedProtocolMessageType('CMsgDOTAKickTeamMember', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAKICKTEAMMEMBER,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAKickTeamMember)
  ))
_sym_db.RegisterMessage(CMsgDOTAKickTeamMember)

CMsgDOTAKickTeamMemberResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAKickTeamMemberResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAKICKTEAMMEMBERRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAKickTeamMemberResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAKickTeamMemberResponse)

CMsgDOTATransferTeamAdmin = _reflection.GeneratedProtocolMessageType('CMsgDOTATransferTeamAdmin', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATRANSFERTEAMADMIN,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATransferTeamAdmin)
  ))
_sym_db.RegisterMessage(CMsgDOTATransferTeamAdmin)

CMsgDOTATransferTeamAdminResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTATransferTeamAdminResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATRANSFERTEAMADMINRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATransferTeamAdminResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTATransferTeamAdminResponse)

CMsgDOTAChangeTeamSub = _reflection.GeneratedProtocolMessageType('CMsgDOTAChangeTeamSub', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHANGETEAMSUB,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChangeTeamSub)
  ))
_sym_db.RegisterMessage(CMsgDOTAChangeTeamSub)

CMsgDOTAChangeTeamSubResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAChangeTeamSubResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHANGETEAMSUBRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChangeTeamSubResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAChangeTeamSubResponse)

CMsgDOTALeaveTeam = _reflection.GeneratedProtocolMessageType('CMsgDOTALeaveTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAVETEAM,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeaveTeam)
  ))
_sym_db.RegisterMessage(CMsgDOTALeaveTeam)

CMsgDOTALeaveTeamResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALeaveTeamResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAVETEAMRESPONSE,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeaveTeamResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALeaveTeamResponse)

CMsgDOTABetaParticipation = _reflection.GeneratedProtocolMessageType('CMsgDOTABetaParticipation', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTABETAPARTICIPATION,
  __module__ = 'dota_gcmessages_client_team_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTABetaParticipation)
  ))
_sym_db.RegisterMessage(CMsgDOTABetaParticipation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
